# DoiT DocOps Utilities

_Python library and CLI tools for doing DocOps at DoiT_

[![Tests][action-packaging-img]][action-packaging] [![DocOps][action-docops-img]][action-docops]

**Table of contents:**

- [Install](#install)
- [Documentation](#documentation)
  - [Users](#users)
  - [Developers](#developers)

## Install

The [doitintl-docops][pypi-project] package is published to [PyPI][pypi] and
you can install it using [Pip][pip], like so:

<!-- cspell:disable -->
```console
$ pip install doitintl-docops
Collecting doit-docops
  Downloading doitintl_docops-2.0.1-py3-none-any.whl (175 kB)
[...]
Successfully installed doitintl_docops-2.0.1
```
<!-- cspell:emable -->

The [project releases][releases] page has a complete list of all releases and
each release page has links to multiple release assets.

## Documentation

> 📝&nbsp;&nbsp;**Note**
>
> Documentation is sparse at the moment because this project is still in the
> early stages of development.

### Users

- [Glossary utilities][user-gloss]
- [GitBook client][user-gitbook]

### Developers

- [Python development][dev-python]

[action-docops-img]: https://github.com/doitintl/docops-utils/actions/workflows/docops.yaml/badge.svg
[action-docops]: https://github.com/doitintl/docops-utils/actions/workflows/docops.yaml
[action-packaging-img]: https://github.com/doitintl/docops-utils/actions/workflows/packaging.yaml/badge.svg
[action-packaging]: https://github.com/doitintl/docops-utils/actions/workflows/packaging.yaml
[dev-python]: https://github.com/doitintl/docops-python/blob/main/docs/dev/python.md
[pip]: https://pip.pypa.io/en/stable/
[pypi-project]: https://pypi.org/project/doitintl-docops
[pypi]: https://pypi.org/
[releases]: https://github.com/doitintl/docops-python/releases
[user-gitbook]: https://github.com/doitintl/docops-python/blob/main/docs/user/gitbook.md
[user-gloss]: https://github.com/doitintl/docops-python/blob/main/docs/user/gloss.md
